InfoNCELoss
===========

.. currentmodule:: pykeen.losses

.. autoclass:: InfoNCELoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InfoNCELoss.DEFAULT_LOG_ADVERSARIAL_TEMPERATURE
      ~InfoNCELoss.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~InfoNCELoss.process_lcwa_scores
      ~InfoNCELoss.process_slcwa_scores

   .. rubric:: Attributes Documentation

   .. autoattribute:: DEFAULT_LOG_ADVERSARIAL_TEMPERATURE
   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: process_lcwa_scores
   .. automethod:: process_slcwa_scores
